summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSarven Capadisli <csarven@status.net>2009-11-08 22:55:53 +0000
committerSarven Capadisli <csarven@status.net>2009-11-08 22:55:53 +0000
commit5c5a905eb94832f2f33dc6a0a99c77912a7ec09d (patch)
treee1d41526cbf0205e29ede154c001d947bc2f085e
parent6f7e3053baefce2a27fba376b020c2ed555821b7 (diff)
Moved back to using lib twitterapi instead of api for 0.8.x
-rw-r--r--plugins/Realtime/RealtimePlugin.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/Realtime/RealtimePlugin.php b/plugins/Realtime/RealtimePlugin.php
index 0c7c1240c..181927968 100644
--- a/plugins/Realtime/RealtimePlugin.php
+++ b/plugins/Realtime/RealtimePlugin.php
@@ -240,13 +240,13 @@ class RealtimePlugin extends Plugin
// FIXME: this code should be abstracted to a neutral third
// party, like Notice::asJson(). I'm not sure of the ethics
// of refactoring from within a plugin, so I'm just abusing
- // the ApiAction method. Don't do this unless you're me!
+ // the TwitterApiAction method. Don't do this unless you're me!
- require_once(INSTALLDIR.'/lib/api.php');
+ require_once(INSTALLDIR.'/lib/twitterapi.php');
- $act = new ApiAction('/dev/null');
+ $act = new TwitterApiAction('/dev/null');
- $arr = $act->twitterStatusArray($notice, true);
+ $arr = $act->twitter_status_array($notice, true);
$arr['url'] = $notice->bestUrl();
$arr['html'] = htmlspecialchars($notice->rendered);
$arr['source'] = htmlspecialchars($arr['source']);